# noise_robust_differentiator
Python implementation of Pavel Holoborodko's smooth noise-robust differentiators.
See http://www.holoborodko.com/pavel/numerical-methods/numerical-derivative/smooth-low-noise-differentiators/
